@@ -9,8 +9,8 @@ import shutil
 import xlsxwriter
 import csv
 import json
-# from excel_magic.chromium_downloader import check_chromium, download_chromium
-# import requests
+from excel_magic.chromium_downloader import check_chromium, download_chromium
+import requests
 
 __all__ = ['Sheet', 'Dataset', 'open_file']
 
